##  Configuration
In the Automations section of the administration area, configure two automations:
  * [Automation 1: Lifecycle Phase Is Reached](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life?locale=en-US&state=PRODUCTION&version=CLOUD#loiofe9ac3c172fe4d3faf012356d850e8a8__automation-1-lifecycle-phase-is-reached)
  * [Automation 2: Relation Is Added](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life?locale=en-US&state=PRODUCTION&version=CLOUD#loiofe9ac3c172fe4d3faf012356d850e8a8__automation-2-relation-is-added)


**Note**
In scripts, replace placeholder URLs with your values. To learn how to find your base URL, see [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD "Learn about the SAP LeanIX base URL and how to get your subdomain value.").
